@@ -353,7 +353,7 @@ cddb_slave_client_get_disc_title (CDDBSlaveClient *client,
 	}
 
 	CORBA_exception_free (&ev);
-	return *ret == 0 ? NULL : g_strdup (ret);
+	return g_locale_to_utf8 (ret, -1, NULL, NULL, NULL);
 }
 
 /**
@@ -373,7 +373,8 @@ cddb_slave_client_set_disc_title (CDDBSlaveClient *client,
 	objref = client->priv->objref;
 
 	CORBA_exception_init (&ev);
-	GNOME_Media_CDDBSlave2_setDiscTitle (objref, discid, title, &ev);
+	GNOME_Media_CDDBSlave2_setDiscTitle (objref, discid,
+					     title ? title : "", &ev);
 	if (BONOBO_EX (&ev)) {
 		g_warning ("Error setting disc title\n%s",
 			   CORBA_exception_id (&ev));
@@ -405,7 +406,7 @@ cddb_slave_client_get_artist (CDDBSlaveClient *client,
 	}
 
 	CORBA_exception_free (&ev);
-	return *ret == 0 ? NULL : g_strdup (ret);
+	return g_locale_to_utf8 (ret, -1, NULL, NULL, NULL);
 }
 
 void
@@ -421,7 +422,8 @@ cddb_slave_client_set_artist (CDDBSlaveClient *client,
 	objref = client->priv->objref;
 
 	CORBA_exception_init (&ev);
-	GNOME_Media_CDDBSlave2_setArtist (objref, discid, artist, &ev);
+	GNOME_Media_CDDBSlave2_setArtist (objref, discid,
+					  artist ? artist : "", &ev);
 	if (BONOBO_EX (&ev)) {
 		g_warning ("Error setting artist\n%s",
 			   CORBA_exception_id (&ev));
@@ -485,9 +487,11 @@ cddb_slave_client_get_tracks (CDDBSlaveClient *client,
 	ret = g_new (CDDBSlaveClientTrackInfo *, list->_length + 1);
 	for (i = 0; i < list->_length; i++) {
 		ret[i] = g_new (CDDBSlaveClientTrackInfo, 1);
-		ret[i]->name = g_strdup (list->_buffer[i].name);
+		ret[i]->name = g_locale_to_utf8 (list->_buffer[i].name, -1,
+						 NULL, NULL, NULL);
 		ret[i]->length = list->_buffer[i].length;
-		ret[i]->comment = g_strdup (list->_buffer[i].comment);
+		ret[i]->comment = g_locale_to_utf8 (list->_buffer[i].comment,
+						    -1, NULL, NULL, NULL);
 	}
 
 	/* NULL terminator */
@@ -574,7 +578,7 @@ cddb_slave_client_get_comment (CDDBSlaveClient *client,
 	}
 
 	CORBA_exception_free (&ev);
-	return *ret == 0 ? NULL : g_strdup (ret);
+	return g_locale_to_utf8 (ret, -1, NULL, NULL, NULL);
 }
 
 void
@@ -591,7 +595,8 @@ cddb_slave_client_set_comment (CDDBSlaveClient *client,
 
 	CORBA_exception_init (&ev);
 
-	GNOME_Media_CDDBSlave2_setComment (objref, discid, comment, &ev);
+	GNOME_Media_CDDBSlave2_setComment (objref, discid,
+					   comment ? comment : "", &ev);
 	if (BONOBO_EX (&ev)) {
 		g_warning ("Error setting comment\n%s", CORBA_exception_id (&ev));
 	}
@@ -669,7 +674,7 @@ cddb_slave_client_get_genre (CDDBSlaveClient *client,
 	}
 
 	CORBA_exception_free (&ev);
-	return *ret == 0 ? NULL : g_strdup (ret);
+	return g_locale_to_utf8 (ret, -1, NULL, NULL, NULL);
 }
 
 void
@@ -685,7 +690,8 @@ cddb_slave_client_set_genre (CDDBSlaveClient *client,
 	objref = client->priv->objref;
 
 	CORBA_exception_init (&ev);
-	GNOME_Media_CDDBSlave2_setGenre (objref, discid, genre, &ev);
+	GNOME_Media_CDDBSlave2_setGenre (objref, discid,
+					 genre ? genre : "", &ev);
 	if (BONOBO_EX (&ev)) {
 		g_warning ("Error setting genre\n%s",
 			   CORBA_exception_id (&ev));
