@@ -16,9 +16,11 @@
 #include <bonobo.h>
 
 #include "gnome-cd.h"
+#include "cddb.h"
 #include "cdrom.h"
-#include "callbacks.h"
 #include "display.h"
+#include "callbacks.h"
+#include "preferences.h"
 #include "access/factory.h"
 
 #define DEFAULT_THEME "lcd"
@@ -46,7 +48,7 @@ gnome_cd_set_window_title (GnomeCD *gcd,
 
 	if (artist == NULL ||
 	    track == NULL) {
-		title = g_strdup ("Gnome-CD " VERSION);
+		title = g_strdup (_("Gnome CD Player"));
 	} else {
 		title = g_strconcat (artist, " - ", track, NULL);
 	}
@@ -110,7 +112,8 @@ gnome_cd_build_track_list_menu (GnomeCD *gcd)
 	}
 
 	menu = GTK_MENU(gtk_menu_new ());
-	if (gcd->disc_info != NULL) {
+	if (gcd->disc_info != NULL &&
+	    gcd->disc_info->track_info) {
 		int i;
 		for (i = 0; i < gcd->disc_info->ntracks; i++) {
 			char *title;
@@ -195,26 +198,6 @@ make_button_from_widget (GnomeCD *gcd,
 	return button;
 }
 
-static GtkWidget *
-make_button_from_file (GnomeCD *gcd,
-		       const char *filename,
-		       GCallback func,
-		       const char *tooltip,
-		       const char *shortname)
-{
-	GtkWidget *pixmap;
-	char *fullname;
-
-	fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-		   filename, TRUE, NULL);
-	g_return_val_if_fail (fullname != NULL, NULL);
-
-	pixmap = gtk_image_new_from_file (fullname);
-	g_free (fullname);
-
-	return make_button_from_widget (gcd, pixmap, func, tooltip, shortname);
-}
-
 static GtkWidget *
 make_button_from_pixbuf (GnomeCD *gcd,
 			 GdkPixbuf *pixbuf,
@@ -293,7 +276,7 @@ window_destroy_cb (GtkWidget *window,
 	}
 
 	/* Unref the cddb slave */
-	close_cddb_client ();
+	cddb_close_client ();
 
 	/* And the track editor */
 	destroy_track_editor ();
@@ -375,12 +358,9 @@ init_player (void)
 	GnomeCDRomStatus *status;
 	GtkWidget *display_box;
 	GtkWidget *top_hbox, *button_hbox, *option_hbox;
-	GtkWidget *button, *arrow;
+	GtkWidget *button;
 	GdkPixbuf *pixbuf;
 	GError *error = NULL;
-	GtkAdjustment *adj;
-	GtkWidget *slider;
-	char *fullname;
 
 	gcd = g_new0 (GnomeCD, 1);
 
@@ -419,7 +399,6 @@ init_player (void)
 	if (gcd->cdrom == NULL) {
 		if (error != NULL) {
 			gcd_warning ("%s", error);
-			g_error_free (error);
 		}
 	} else {
 		g_signal_connect (G_OBJECT (gcd->cdrom), "status-changed",
@@ -458,7 +437,7 @@ init_player (void)
 	}
 		
 	gcd->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (gcd->window), "Gnome-CD "VERSION);
+	gtk_window_set_title (GTK_WINDOW (gcd->window), _("Gnome CD Player"));
 	gtk_window_set_wmclass (GTK_WINDOW (gcd->window), "main_window", "gnome-cd");
 	gtk_window_set_default_size (GTK_WINDOW (gcd->window), 350, 129);
 	
@@ -500,10 +479,12 @@ init_player (void)
 	gtk_box_pack_start (GTK_BOX (top_hbox), display_box, TRUE, TRUE, 0);
 
 	/* Volume slider */
-	gcd->slider = gtk_vscale_new_with_range (0.0, 255.0, 1.0);
-	gtk_range_set_inverted (GTK_RANGE (gcd->slider), TRUE);
+	gcd->slider = gtk_vscale_new_with_range (-255.0, 0.0, 1.0);
 	gtk_scale_set_draw_value (GTK_SCALE (gcd->slider), FALSE);
 	gtk_box_pack_start (GTK_BOX (top_hbox), gcd->slider, FALSE, FALSE, 0);
+	
+	gtk_tooltips_set_tip (gcd->tooltips, GTK_WIDGET (gcd->slider),
+			      _("Volume control"), NULL);
 
 	gtk_box_pack_start (GTK_BOX (gcd->vbox), top_hbox, TRUE, TRUE, 0);
 
@@ -528,8 +509,10 @@ init_player (void)
 	gcd->tracks = gtk_option_menu_new ();
 	g_signal_connect (G_OBJECT (gcd->tracks), "changed",
 			  G_CALLBACK (skip_to_track), gcd);
+	gtk_tooltips_set_tip (gcd->tooltips, GTK_WIDGET (gcd->tracks), 
+			      _("Track List"), NULL );
 	gnome_cd_build_track_list_menu (gcd);
-	gtk_box_pack_start (GTK_BOX (option_hbox), gcd->tracks, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (option_hbox), gcd->tracks, TRUE, TRUE, 0);
 
 	gtk_box_pack_start (GTK_BOX (gcd->vbox), option_hbox, FALSE, FALSE, 0);
 	
@@ -630,12 +613,13 @@ static gint client_die(GnomeClient *client,
 
 
 int 
-main (int argc,
-      char *argv[])
+main (int argc, char *argv[])
 {
 	GnomeCD *gcd;
 	GnomeClient *client;
 
+	free (malloc (8)); /* -lefence */
+
 	if (g_getenv ("GNOME_CD_DEBUG")) {
 		debug_mode = TRUE;
 	}
@@ -644,9 +628,8 @@ main (int argc,
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("Gnome-CD", VERSION, LIBGNOMEUI_MODULE, 
-			    argc, argv, NULL);
-	gconf_init (argc, argv, NULL);
+	gnome_program_init ("gnome-cd", VERSION, LIBGNOMEUI_MODULE, 
+			    argc, argv, GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 	client = gnome_master_client ();
     	g_signal_connect (client, "save_yourself",
                          G_CALLBACK (save_session), (gpointer) argv[0]);
@@ -686,7 +669,7 @@ main (int argc,
 	
 	gtk_widget_show (gcd->window);
 
-	setup_factory();
+	setup_a11y_factory ();
 
 	bonobo_main ();
 	return 0;
