@@ -24,12 +24,17 @@
 #include <config.h>
 #endif
 
+#include <string.h>
 #include <sys/types.h>
 #include <dirent.h>
 
+#include <atk/atk.h>
+
 #include <gtk/gtkdialog.h>
+#include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkvbox.h>
+#include <gtk/gtkframe.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkcheckbutton.h>
@@ -39,6 +44,8 @@
 #include <gtk/gtkliststore.h>
 #include <gtk/gtkcellrenderer.h>
 #include <gtk/gtktreeviewcolumn.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtktreeview.h>
 
 #include <gtk/gtkscrolledwindow.h>
@@ -56,13 +63,29 @@ static void
 do_device_changed (GnomeCDPreferences *prefs,
 		   const char *device)
 {
+	GError *error = NULL;
+	gboolean ret;
+	
 	if (prefs->device != NULL) {
 		g_free (prefs->device);
 	}
 
 	prefs->device = g_strdup (device);
 	if (prefs->gcd->cdrom != NULL) {
-		gnome_cdrom_set_device (prefs->gcd->cdrom, prefs->device, NULL);
+		ret = gnome_cdrom_set_device (prefs->gcd->cdrom, prefs->device, &error);
+		if (ret == FALSE) {
+			GtkWidget *dialog;
+
+			dialog = gtk_message_dialog_new (NULL, 0,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_OK,
+							 _("%s\nThis means that Gnome-CD will not be able to run."), error->message);
+			gtk_window_set_title (GTK_WINDOW (dialog), _("Error setting device"));
+			g_signal_connect (G_OBJECT (dialog), "response",
+					  G_CALLBACK (gtk_widget_destroy), dialog);
+			gtk_widget_show (dialog);
+			g_error_free (error);
+		}
 	}
 }
 
@@ -220,15 +243,8 @@ restore_preferences (GnomeCDPreferences *prefs)
 void
 preferences_free (GnomeCDPreferences *prefs)
 {
-	GConfClient *client;
-	
-	if (prefs->device != NULL) {
-		g_free (prefs->device);
-	}
-
-	if (prefs->theme_name != NULL) {
-		g_free (prefs->theme_name);
-	}
+	g_free (prefs->device);
+	g_free (prefs->theme_name);
 
 	/* Remove the listeners */
 	gconf_client_notify_remove (client, prefs->device_id);
@@ -247,7 +263,7 @@ preferences_new (GnomeCD *gcd)
 {
 	GnomeCDPreferences *prefs;
 
-	prefs = g_new (GnomeCDPreferences, 1);
+	prefs = g_new0 (GnomeCDPreferences, 1);
 	prefs->gcd = gcd;
 
 	client = gconf_client_get_default ();
@@ -298,6 +314,7 @@ prefs_response_cb (GtkWidget *dialog,
 		   int response_id,
 		   PropertyDialog *pd)
 {
+	GError *error = NULL;
 	switch (response_id) {
 	case GTK_RESPONSE_CLOSE:
 	case GTK_RESPONSE_NONE:
@@ -305,6 +322,27 @@ prefs_response_cb (GtkWidget *dialog,
 		gtk_widget_destroy (dialog);
 		break;
 
+	case GTK_RESPONSE_HELP:
+		gnome_help_display("gnome-cd","gtcd-prefs",&error);
+		if (error) {
+			GtkWidget *msg_dialog;
+			msg_dialog = gtk_message_dialog_new (GTK_WINDOW(dialog),
+							     GTK_DIALOG_DESTROY_WITH_PARENT,
+							     GTK_MESSAGE_ERROR,
+							     GTK_BUTTONS_CLOSE,
+							     ("There was an error displaying help: \n%s"),
+							     error->message);
+			g_signal_connect (G_OBJECT (msg_dialog), "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  NULL);
+	
+			gtk_window_set_resizable (GTK_WINDOW (msg_dialog), FALSE);
+			gtk_widget_show (msg_dialog);
+			g_error_free (error);
+		}
+		break;
+
+
 	default:
 		g_print ("Response %d\n", response_id);
 		g_assert_not_reached ();
@@ -331,19 +369,16 @@ static void
 apply_clicked_cb (GtkWidget *apply,
 		  PropertyDialog *pd)
 {
-	char *new_device;
+	const char *new_device;
 
 	new_device = gtk_entry_get_text (GTK_ENTRY (pd->cd_device));
 	
-	if (new_device == NULL) {
+	if (!new_device)
 		return;
-	}
 
-	if (pd->gcd->preferences->device != NULL) {
-		if (strcmp (new_device, pd->gcd->preferences->device) == 0) {
-			return;
-		}
-	}
+	if (pd->gcd->preferences->device &&
+	    strcmp (new_device, pd->gcd->preferences->device) == 0)
+		return;
 	
 	gconf_client_set_string (client, "/apps/gnome-cd/device", new_device, NULL);
 	gtk_widget_set_sensitive (pd->apply, FALSE);
@@ -353,7 +388,7 @@ static void
 device_changed_cb (GtkWidget *entry,
 		   PropertyDialog *pd)
 {
-	char *new_device;
+	const char *new_device;
 
 	new_device = gtk_entry_get_text (GTK_ENTRY (entry));
 	if (new_device == NULL || *new_device == 0) {
@@ -492,7 +527,7 @@ change_start_widget (GConfClient *client,
 {
 	PropertyDialog *pd = user_data;
 	GConfValue *value = gconf_entry_get_value (entry);
-	GCallback *func;
+	GCallback func;
 	GtkToggleButton *tb;
 	
 	switch (gconf_value_get_int (value)) {
@@ -531,7 +566,7 @@ change_stop_widget (GConfClient *client,
 {
 	PropertyDialog *pd = user_data;
 	GConfValue *value = gconf_entry_get_value (entry);
-	GCallback *func;
+	GCallback func;
 	GtkToggleButton *tb;
 
 	switch (gconf_value_get_int (value)) {
@@ -687,7 +722,51 @@ create_theme_model (PropertyDialog *pd,
 
 	return GTK_TREE_MODEL (store);
 }
-	
+
+static void
+add_relation (AtkRelationSet *set,
+	      AtkRelationType type,
+	      AtkObject *target)
+{
+	AtkRelation *relation;
+
+	relation = atk_relation_set_get_relation_by_type (set, type);
+
+	if (relation != NULL) {
+		GPtrArray *array = atk_relation_get_target (relation);
+
+		g_ptr_array_remove (array, target);
+		g_ptr_array_add (array, target);
+	} else {
+		/* Relation hasn't been created yet */
+		relation = atk_relation_new (&target, 1, type);
+
+		atk_relation_set_add (set, relation);
+		g_object_unref (relation);
+	}
+}
+
+static void
+add_paired_relations (GtkWidget *target1,
+		      AtkRelationType target1_type,
+		      GtkWidget *target2,
+		      AtkRelationType target2_type)
+{
+	AtkObject *atk_target1;
+	AtkObject *atk_target2;
+	AtkRelationSet *set1;
+	AtkRelationSet *set2;
+
+	atk_target1 = gtk_widget_get_accessible (target1);
+	atk_target2 = gtk_widget_get_accessible (target2);
+
+	set1 = atk_object_ref_relation_set (atk_target1);
+	add_relation (set1, target1_type, atk_target2);
+
+	set2 = atk_object_ref_relation_set (atk_target2);
+	add_relation (set2, target2_type, atk_target1);
+}
+
 GtkWidget *
 preferences_dialog_show (GnomeCD *gcd,
 			 gboolean only_device)
@@ -700,9 +779,8 @@ preferences_dialog_show (GnomeCD *gcd,
 	GtkTreeViewColumn *col;
 	GtkTreeModel *model;
 	GtkTreeSelection *selection;
-	GtkTreeIter sel_iter;
 	
-	pd = g_new (PropertyDialog, 1);
+	pd = g_new0 (PropertyDialog, 1);
 	
 	pd->gcd = gcd;
 
@@ -712,9 +790,10 @@ preferences_dialog_show (GnomeCD *gcd,
 		windy = NULL;
 	}
 	
-	pd->window = gtk_dialog_new_with_buttons (_("Gnome-CD Preferences"),
+	pd->window = gtk_dialog_new_with_buttons (_("Gnome CD Player Preferences"),
 						  windy,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 	if (only_device == FALSE) {
 		g_signal_connect (G_OBJECT (pd->window), "response",
@@ -736,6 +815,9 @@ preferences_dialog_show (GnomeCD *gcd,
 	pd->cd_device = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY (pd->cd_device), gcd->preferences->device);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->cd_device);
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR,
+			      pd->cd_device, ATK_RELATION_LABELLED_BY);
+	
 	g_signal_connect (G_OBJECT (pd->cd_device), "changed",
 			  G_CALLBACK (device_changed_cb), pd);
 	g_signal_connect (G_OBJECT (pd->cd_device), "activate",
@@ -755,7 +837,7 @@ preferences_dialog_show (GnomeCD *gcd,
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pd->window)->vbox), hbox, FALSE, FALSE, 4);
 
 	/* left side */
-	frame = gtk_frame_new (_("When Gnome-CD starts"));
+	frame = gtk_frame_new (_("When Gnome CD Player starts"));
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
 	gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
 	
@@ -806,7 +888,7 @@ preferences_dialog_show (GnomeCD *gcd,
 						change_start_close_widget, pd, NULL, NULL);
 #endif
 	/* Right side */
-	frame = gtk_frame_new (_("When Gnome-CD quits"));
+	frame = gtk_frame_new (_("When Gnome CD Player quits"));
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
 	gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
 
@@ -861,9 +943,9 @@ preferences_dialog_show (GnomeCD *gcd,
 	
 	/* Theme selector */
 	pd->theme_list = gtk_tree_view_new ();
-	selection = gtk_tree_view_get_selection (pd->theme_list);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pd->theme_list));
 
-	model = create_theme_model (pd, pd->theme_list, selection);
+	model = create_theme_model (pd, GTK_TREE_VIEW (pd->theme_list), selection);
 	if (model == NULL) {
 		/* Should free stuff here */
 		return NULL;
@@ -897,3 +979,4 @@ preferences_dialog_show (GnomeCD *gcd,
 	
 	return pd->window;
 }
+
