@@ -38,6 +38,7 @@
 #include "prog.h"
 
 static GConfClient *client = NULL;
+static void prefs_help_cb (GtkWidget *widget, gpointer data);
 
 static GnomeUIInfo arkiv1_menu_uiinfo[] =
 {
@@ -48,14 +49,16 @@ static GnomeUIInfo arkiv1_menu_uiinfo[] =
 	GNOMEUIINFO_MENU_SAVE_ITEM (on_save_activate_cb, NULL),
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_saveas_activate_cb, NULL),
 	GNOMEUIINFO_SEPARATOR,
+#ifdef HAVE_MIXER
 	{
 		GNOME_APP_UI_ITEM, N_("Run _Mixer"),
 		N_("Run GNOME Volume Control"),
 		on_runmixer_activate_cb, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_VOLUME,
-		0, 0, NULL
+		'r',GDK_CONTROL_MASK, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
+#endif
 	GNOMEUIINFO_MENU_EXIT_ITEM (on_exit_activate_cb, NULL),
 	GNOMEUIINFO_END
 };
@@ -159,7 +162,6 @@ GtkWidget*
 create_grecord_window (void)
 {
 	GtkWidget* vbox;
-	GtkWidget* menubar;
 	GtkWidget* toolbar;
 	GtkWidget* tmp_toolbar_icon;
 	GtkWidget* hbox1;
@@ -189,6 +191,7 @@ create_grecord_window (void)
 
 	grecord_window = gnome_app_new ("gnome-sound-recorder", "gnome-sound-recorder");
 	gtk_window_set_title (GTK_WINDOW (grecord_window), _("Sound Recorder"));
+	gtk_window_set_resizable (GTK_WINDOW (grecord_window), FALSE);
 	
 	if (!audioformat)
 		audioformat_string = g_strdup (_("16bit PCM"));
@@ -200,10 +203,8 @@ create_grecord_window (void)
 	else
 		channels_string = g_strdup (_("mono"));
 
-	menubar = gtk_menu_bar_new ();
-	gtk_widget_show (menubar);
-	gnome_app_fill_menu (GTK_MENU_SHELL (menubar), menubar1_uiinfo,
-			     NULL, FALSE, 0);
+	/* Create menus */
+	gnome_app_create_menus (GNOME_APP (grecord_window), menubar1_uiinfo);
 
 	toolbar = gtk_toolbar_new ();
 	gtk_widget_show (toolbar);
@@ -342,7 +343,6 @@ create_grecord_window (void)
 
 	/* Gnome stuff */
 	gnome_app_set_statusbar (GNOME_APP (grecord_window),  GTK_WIDGET (grecord_appbar));
-	gnome_app_set_menus (GNOME_APP (grecord_window), GTK_MENU_BAR (menubar));
 	gnome_app_set_toolbar (GNOME_APP (grecord_window), GTK_TOOLBAR (toolbar));
 	gnome_app_set_contents (GNOME_APP (grecord_window), GTK_WIDGET (vbox));
 
@@ -446,6 +446,10 @@ response_cb (GtkDialog *dialog,
 	     int response_id,
 	     gpointer data)
 {
+	if (response_id == GTK_RESPONSE_HELP) {
+		prefs_help_cb (NULL, NULL);
+		return;
+	}
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
@@ -698,7 +702,9 @@ create_grecord_propertybox (void)
 							   GTK_WINDOW (grecord_widgets.grecord_window),
 							   GTK_DIALOG_DESTROY_WITH_PARENT,
 							   GTK_STOCK_CLOSE,
-							   GTK_RESPONSE_CLOSE, NULL);
+							   GTK_RESPONSE_CLOSE,
+							   GTK_STOCK_HELP,
+							   GTK_RESPONSE_HELP,NULL);
 	gtk_window_set_title (GTK_WINDOW (grecord_propertybox), _("Sound Recorder Preferences"));
 	g_signal_connect (G_OBJECT (grecord_propertybox), "response",
 			  G_CALLBACK (response_cb), NULL);
@@ -1203,3 +1209,16 @@ add_paired_relations (GtkWidget* target1, AtkRelationType target1_type,
 	target2_relation_set = atk_object_ref_relation_set (atk_target2);
 	add_relation (target2_relation_set, target2_type, atk_target1);
 }
+
+static void
+prefs_help_cb (GtkWidget *widget,
+	       gpointer data)
+{
+	GError *error = NULL;
+	gnome_help_display ("grecord", "grecord-prefs", &error);
+
+	if (error) {
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+	}
+}
